pub enum ChipVariant {
Assist,
Filter,
Input,
Suggestion,
}Expand description
Material Design chip variants following Material Design 3 specifications
Variants
Assist
Assist chips help users take actions or get information about their current context
Filter
Filter chips let users refine content by selecting or deselecting options
Input
Input chips represent discrete pieces of information entered by a user
Suggestion
Suggestion chips help users discover relevant, actionable content