MaterialImageList

Struct MaterialImageList 

pub struct MaterialImageList<'a> { /* private fields */ }
Material Design image list component.

Image lists display a collection of images in an organized grid. They’re commonly used to display a collection of photos or other images.

let image_list = MaterialImageList::standard()
    .columns(3)
    .item("Image 1", "320x240.png")
    .item("Image 2", "320x240.png")
    .item("Image 3", "320x240.png");

ui.add(image_list);

Implementations

Source

impl<'a> MaterialImageList<'a>

pub fn standard() -> Self

Create a new standard image list.

pub fn masonry() -> Self

Create a new masonry image list.

pub fn woven() -> Self

Create a new woven image list.

pub fn columns(self, columns: usize) -> Self

Set number of columns.

pub fn item( self, label: impl Into<String>, image_source: impl Into<String>, ) -> Self

Add an image item.

pub fn item_with_callback<F>( self, label: impl Into<String>, image_source: impl Into<String>, callback: F, ) -> Self
where F: Fn() + Send + Sync + 'static,

Add an image item with callback.

pub fn item_spacing(self, spacing: f32) -> Self

Set item spacing.

pub fn text_protected(self, protected: bool) -> Self

Enable text protection overlay.

pub fn corner_radius(self, corner_radius: impl Into<CornerRadius>) -> Self

Set corner radius.

pub fn id_salt(self, salt: impl Into<String>) -> Self

Set unique ID salt to prevent ID clashes.

pub fn items_from_paths<I, P>(self, paths: I) -> Self
where I: IntoIterator<Item = P>, P: AsRef<Path>,

Add items from a collection of file paths.

pub fn items_from_urls<I, S>(self, urls: I) -> Self
where I: IntoIterator<Item = S>, S: Into<String>,

Add items from a collection of URLs.

pub fn items_from_bytes<I>(self, bytes_collection: I) -> Self
where I: IntoIterator<Item = Vec<u8>>,

Add items from a collection of byte arrays (for embedded images).