GridTile

Struct GridTile 

pub struct GridTile<'a> { /* private fields */ }
Material Design grid tile.

A tile in a grid list with optional header and footer overlays. Based on Flutter’s GridTile component.

let tile = GridTile::new(|ui| {
    ui.label("Tile content");
})
.footer(
    GridTileBar::new()
        .title("Image Title")
        .background_color(egui::Color32::from_black_alpha(128))
);

ui.add(tile);

Implementations

Source

impl<'a> GridTile<'a>

pub fn new<F>(content: F) -> Self
where F: FnOnce(&mut Ui) + 'a,

Create a new grid tile with the given content.

pub fn header(self, header: GridTileBar<'a>) -> Self

Set the header bar (shown at the top).

pub fn footer(self, footer: GridTileBar<'a>) -> Self

Set the footer bar (shown at the bottom).

pub fn min_height(self, height: f32) -> Self

Set the minimum height of the tile.