pub enum ListTileStyle {
List,
Drawer,
}Expand description
Defines the title font used for ListTile descendants.
List tiles that appear in a drawer use a smaller text style, while standard list tiles use the default title text style.
Variants
List
Use a title font appropriate for a list tile in a list.
Drawer
Use a title font appropriate for a list tile in a drawer.