pub enum SnackBarBehavior {
Fixed,
Floating,
}Expand description
Defines where a SnackBar should appear and how its location should be adjusted.
Variants
Fixed
Fixes the SnackBar at the bottom of the screen. The snackbar will have no margin and appear directly at the bottom.
Floating
The snackbar will float above the bottom with margins. This allows for custom width and spacing from screen edges.