TimelinePosition

Enum TimelinePosition 

pub enum TimelinePosition {
    Left,
    Right,
    Alternate,
    AlternateReverse,
}
Position where timeline content appears relative to the timeline axis.

Variants



Left

Content appears on the left side of the timeline



Right

Content appears on the right side of the timeline



Alternate

Content alternates between left and right sides



AlternateReverse

Content alternates between right and left sides (starts on right)