pub struct MaterialImageList<'a> { /* private fields */ }Expand description
Material Design image list component.
Image lists display a collection of images in an organized grid. They’re commonly used to display a collection of photos or other images.
let image_list = MaterialImageList::standard()
.columns(3)
.item("Image 1", "320x240.png")
.item("Image 2", "320x240.png")
.item("Image 3", "320x240.png");
ui.add(image_list);Implementations
Sourceimpl<'a> MaterialImageList<'a>
impl<'a> MaterialImageList<'a>
Sourcepub fn item(
self,
label: impl Into<String>,
image_source: impl Into<String>,
) -> Self
pub fn item( self, label: impl Into<String>, image_source: impl Into<String>, ) -> Self
Add an image item.
Sourcepub fn item_with_callback<F>(
self,
label: impl Into<String>,
image_source: impl Into<String>,
callback: F,
) -> Self
pub fn item_with_callback<F>( self, label: impl Into<String>, image_source: impl Into<String>, callback: F, ) -> Self
Add an image item with callback.
Sourcepub fn item_spacing(self, spacing: f32) -> Self
pub fn item_spacing(self, spacing: f32) -> Self
Set item spacing.
Sourcepub fn text_protected(self, protected: bool) -> Self
pub fn text_protected(self, protected: bool) -> Self
Enable text protection overlay.
Sourcepub fn corner_radius(self, corner_radius: impl Into<CornerRadius>) -> Self
pub fn corner_radius(self, corner_radius: impl Into<CornerRadius>) -> Self
Set corner radius.
Sourcepub fn id_salt(self, salt: impl Into<String>) -> Self
pub fn id_salt(self, salt: impl Into<String>) -> Self
Set unique ID salt to prevent ID clashes.
Sourcepub fn items_from_paths<I, P>(self, paths: I) -> Self
pub fn items_from_paths<I, P>(self, paths: I) -> Self
Add items from a collection of file paths.
Sourcepub fn items_from_urls<I, S>(self, urls: I) -> Self
pub fn items_from_urls<I, S>(self, urls: I) -> Self
Add items from a collection of URLs.
Sourcepub fn items_from_bytes<I>(self, bytes_collection: I) -> Self
pub fn items_from_bytes<I>(self, bytes_collection: I) -> Self
Add items from a collection of byte arrays (for embedded images).