pub enum ListTileTitleAlignment {
ThreeLine,
TitleHeight,
Top,
Center,
Bottom,
}Expand description
Defines how leading and trailing widgets are vertically aligned relative to the list tile’s titles (title and subtitle).
Variants
ThreeLine
The top of leading/trailing widgets are placed below the title top if three-line, otherwise centered relative to title and subtitle. This is the default for Material 3.
TitleHeight
Leading/trailing are placed 16px below title top if tile height > 72, otherwise centered. This is the default for Material 2.
Top
Leading/trailing tops are placed at min vertical padding below title top.
Center
Leading/trailing are centered relative to the titles.
Bottom
Leading/trailing bottoms are placed at min vertical padding above title bottom.