VisualDensity

Struct VisualDensity 

pub struct VisualDensity {
    pub horizontal: f32,
    pub vertical: f32,
}
Defines the visual density for the list tile layout.

Visual density allows for compact, comfortable, or spacious layouts.

Fields

horizontal: f32

Horizontal density adjustment (-4.0 to 4.0)

vertical: f32

Vertical density adjustment (-4.0 to 4.0)

Implementations

Source

impl VisualDensity

pub const STANDARD: Self

Standard density (no adjustment)

pub const COMFORTABLE: Self

Comfortable density (slightly more spacious)

pub const COMPACT: Self

Compact density (space-efficient)

pub fn new(horizontal: f32, vertical: f32) -> Self

Create a custom visual density

pub fn base_size_adjustment(&self) -> Vec2

Get the base size adjustment as a Vec2