pub struct VisualDensity {
pub horizontal: f32,
pub vertical: f32,
}Expand description
Defines the visual density for the list tile layout.
Visual density allows for compact, comfortable, or spacious layouts.
Fields
horizontal: f32Horizontal density adjustment (-4.0 to 4.0)
vertical: f32Vertical density adjustment (-4.0 to 4.0)
Implementations
Sourceimpl VisualDensity
impl VisualDensity
Sourcepub const COMFORTABLE: Self
pub const COMFORTABLE: Self
Comfortable density (slightly more spacious)
Sourcepub fn base_size_adjustment(&self) -> Vec2
pub fn base_size_adjustment(&self) -> Vec2
Get the base size adjustment as a Vec2