pub struct MaterialSelect<'a> { /* private fields */ }Expand description
Material Design select/dropdown component.
Select components allow users to choose one option from a list. They display the currently selected option in a text field-style input and show all options in a dropdown menu when activated.
Example
let mut selected = Some(1);
ui.add(MaterialSelect::new(&mut selected)
.placeholder("Choose an option")
.option(0, "Option 1")
.option(1, "Option 2")
.option(2, "Option 3")
.helper_text("Select your preferred option"));Implementations
Sourceimpl<'a> MaterialSelect<'a>
impl<'a> MaterialSelect<'a>
Sourcepub fn placeholder(self, placeholder: impl Into<String>) -> Self
pub fn placeholder(self, placeholder: impl Into<String>) -> Self
Sourcepub fn error_text(self, text: impl Into<String>) -> Self
pub fn error_text(self, text: impl Into<String>) -> Self
Sourcepub fn helper_text(self, text: impl Into<String>) -> Self
pub fn helper_text(self, text: impl Into<String>) -> Self
Sourcepub fn leading_icon(self, icon: impl Into<String>) -> Self
pub fn leading_icon(self, icon: impl Into<String>) -> Self
Sourcepub fn trailing_icon(self, icon: impl Into<String>) -> Self
pub fn trailing_icon(self, icon: impl Into<String>) -> Self
Sourcepub fn keep_open_on_select(self, keep_open: bool) -> Self
pub fn keep_open_on_select(self, keep_open: bool) -> Self
Set whether to keep the dropdown open after selecting an option.
Arguments
keep_open- If true, the dropdown remains open after selection; if false, it closes (default behavior)
Example
let mut selection = None;
ui.add(MaterialSelect::new(&mut selection)
.keep_open_on_select(true)); // Dropdown stays open after selectionTrait Implementations